@@ -1,14 +1,13 @@
 from watchpoints import watch as snap, watch_element
-from .shared import output
+from .shared import output, scope
 from .time import getTime
-
-output["scope"] = {}
+import copy
 
 def registerVariableChange(frame: watch_element.WatchElement, elem, info):
 	line = info[2]
 	value = elem.obj
 	name = elem.localvar
-	output["scope"][name] = value
+	scope[name] = value
 	output["snapshots"].append({
 		"time": getTime(),
 		"event": {
@@ -18,7 +17,7 @@ def registerVariableChange(frame: watch_element.WatchElement, elem, info):
 			"value": value
 		},
 		"context": {},
-		"scope": output["scope"]
+		"scope": copy.deepcopy(scope)
 	})
 
 snap.config(custom_printer=lambda x: x, callback=registerVariableChange)
\ No newline at end of file
